package WebGUI::i18n::Spanish::Asset_GalleryAlbum;
use utf8;
our $I18N = {
  'Adding %s to album' => {
    'lastUpdated' => '1255726056',
    'message' => 'Agregando %s al Album'
  },
  'Extracting archive' => {
    'lastUpdated' => '1255726072',
    'message' => 'Extrayendo archivos'
  },
  'Found file: %s' => {
    'lastUpdated' => '1255726082',
    'message' => 'Encontré el archivo %s'
  },
  'Getting list of files for sorting purposes' => {
    'lastUpdated' => '1289571456',
    'message' => 'Preparando la lista de archivos a ordenar'
  },
  'Requesting commit for version tag' => {
    'lastUpdated' => '1255726101',
    'message' => 'Consignando Versión'
  },
  'Uploading archive' => {
    'lastUpdated' => '1255726111',
    'message' => 'Subiendo archivos'
  },
  'add photo' => {
    'lastUpdated' => '1252535878',
    'message' => 'Agregar Foto'
  },
  'addArchive error generic' => {
    'lastUpdated' => '1252535901',
    'message' => 'Ocurrió un error al incorporar su archivo: %s'
  },
  'addArchive error too big' => {
    'lastUpdated' => '1252535922',
    'message' => 'El archivo que intenta incorporar es demasiado grande. Por favor intente de nuevo.'
  },
  'addArchive file' => {
    'lastUpdated' => '1252535933',
    'message' => 'Archivo'
  },
  'addArchive friendsOnly' => {
    'lastUpdated' => '1252535944',
    'message' => 'Amigos Solamente'
  },
  'addArchive keywords' => {
    'lastUpdated' => '1252535954',
    'message' => 'Etiquetas'
  },
  'addArchive location' => {
    'lastUpdated' => '1276810158',
    'message' => 'Ubicación'
  },
  'addArchive message' => {
    'lastUpdated' => '1252536030',
    'message' => 'Sus archivos han sido incorporados y esperan aprobación. %s'
  },
  'addArchive sortBy' => {
    'lastUpdated' => '1276810169',
    'message' => 'Ordenar por'
  },
  'addArchive sortBy date' => {
    'lastUpdated' => '1276810183',
    'message' => 'Fecha'
  },
  'addArchive sortBy fileOrder' => {
    'lastUpdated' => '1276810208',
    'message' => 'Orden de Archivo'
  },
  'addArchive sortBy name' => {
    'lastUpdated' => '1276810216',
    'message' => 'Nombre'
  },
  'assetName' => {
    'lastUpdated' => '1252536058',
    'message' => 'Galería de Albumes'
  },
  'cancel' => {
    'lastUpdated' => '1203365582',
    'message' => 'Cancelar'
  },
  'delete message' => {
    'lastUpdated' => '1252536072',
    'message' => 'El Album ha sido eliminado. %s'
  },
  'editForm assetIdThumbnail label' => {
    'lastUpdated' => '1252536104',
    'message' => 'Seleccione una miniatura para representar su Album.'
  },
  'editForm description label' => {
    'lastUpdated' => '1252536379',
    'message' => 'Descripción del Album'
  },
  'editForm othersCanAdd label' => {
    'lastUpdated' => '1252536420',
    'message' => 'Otros pueden Agregar'
  },
  'editForm title label' => {
    'lastUpdated' => '1252536458',
    'message' => 'Título'
  },
  'help addArchive body' => {
    'lastUpdated' => '1252536482',
    'message' => 'Estas variables están disponibles en la página Agregar Archivo al Album.'
  },
  'help addArchive title' => {
    'lastUpdated' => '1252536531',
    'message' => 'Variables para Agregar Archivo en Album de Galería'
  },
  'help common body' => {
    'lastUpdated' => '1252536765',
    'message' => 'Estas variables son comunes a todas las páginas de Albumes.'
  },
  'help common title' => {
    'lastUpdated' => '1252536793',
    'message' => 'Variables de Galerías de Albumes'
  },
  'help delete body' => {
    'lastUpdated' => '1252536879',
    'message' => 'Estas variables están disponibles en la página de Eliminar Album.'
  },
  'help delete title' => {
    'lastUpdated' => '1252536835',
    'message' => 'Variables en Eliminar Album de Galería'
  },
  'help edit body' => {
    'lastUpdated' => '1252536865',
    'message' => 'Estas variables estan disponibles en la página de Editar Album.'
  },
  'help edit title' => {
    'lastUpdated' => '1252536908',
    'message' => 'Variables de Editar Album de Galería'
  },
  'help fileLoop body' => {
    'lastUpdated' => '1252536934',
    'message' => 'Estas variables son comunes a todas las páginas que iteran sobre Archivos.'
  },
  'help fileLoop title' => {
    'lastUpdated' => '1252537016',
    'message' => 'Variables de ciclos para Archivos en Albumes de Galería'
  },
  'help slideshow body' => {
    'lastUpdated' => '1252540076',
    'message' => 'Estas variables están disponibles en la página SlideShow del Album.'
  },
  'help slideshow title' => {
    'lastUpdated' => '1252540099',
    'message' => 'Variables de SlideShow Album de Galería'
  },
  'help thumbnails body' => {
    'lastUpdated' => '1252540121',
    'message' => 'Estas variables están disponibles en la página de miniaturas del Album.'
  },
  'help thumbnails title' => {
    'lastUpdated' => '1252540155',
    'message' => 'Variables para Miniaturas de Album en Galería'
  },
  'help view body' => {
    'lastUpdated' => '1252540179',
    'message' => 'Estas variables están disponibles en la página de mostrar Album'
  },
  'help view title' => {
    'lastUpdated' => '1252540199',
    'message' => 'Variables de Ver Album de Galería'
  },
  'help viewRss body' => {
    'lastUpdated' => '1252540216',
    'message' => 'Estas variables están disponibles en la Fuente RSS del Album'
  },
  'help viewRss title' => {
    'lastUpdated' => '1252540231',
    'message' => 'Variables de Fuente RSS de Album de Galería'
  },
  'helpvar canAddFile' => {
    'lastUpdated' => '1252540253',
    'message' => 'Un condicional que indica si el usuario puede o no agregar Archivos al Album.'
  },
  'helpvar canEdit' => {
    'lastUpdated' => '1252540272',
    'message' => 'Un condicional que indica si el usuario puede editar este Album o no.'
  },
  'helpvar error' => {
    'lastUpdated' => '1252540279',
    'message' => 'Un mensaje de error para mostrar&nbsp; al usuario.&nbsp; Solamente definido cuando algo salió mal.'
  },
  'helpvar fileCount' => {
    'lastUpdated' => '1252540288',
    'message' => 'El número de archivos en este Album.'
  },
  'helpvar file_' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'helpvar file_*' => {
    'lastUpdated' => '1252540325',
    'message' => 'El Archivo siendo mostrado actualmente en la página de miniaturas. Todas las variables comunes para el Archivo están disponibles con el prefijo "file_".'
  },
  'helpvar file_loop' => {
    'lastUpdated' => '1252540342',
    'message' => 'Un ciclo que itera sobre los Archivos a presentar en la página.'
  },
  'helpvar file_loop edit' => {
    'lastUpdated' => '1252540365',
    'message' => 'Un ciclo que itera sobre los Archivos a editar en la página de Editar Album.'
  },
  'helpvar file_loop viewRss' => {
    'lastUpdated' => '1252540391',
    'message' => 'Un ciclo sobre los archivos para una Fuente RSS que incluye variables adicionales.'
  },
  'helpvar form_archive' => {
    'lastUpdated' => '1215798053',
    'message' => 'El archivo para subir. Un control WebGUI::Form::File '
  },
  'helpvar form_cancel' => {
    'lastUpdated' => '1252540400',
    'message' => 'Cancelar'
  },
  'helpvar form_delete' => {
    'lastUpdated' => '1252540411',
    'message' => 'Un botón para eliminar la imagen.'
  },
  'helpvar form_demote' => {
    'lastUpdated' => '1252540436',
    'message' => 'Un botón para mover la imagen hacia abajo en el orden jerárquico. Se usa para cambiar el orden de las imágenes.'
  },
  'helpvar form_description' => {
    'lastUpdated' => '1252540447',
    'message' => 'La descripción del Album.'
  },
  'helpvar form_end' => {
    'lastUpdated' => '1252540457',
    'message' => 'El final del formulario.'
  },
  'helpvar form_friendsOnly' => {
    'lastUpdated' => '1252540483',
    'message' => '¿Archivo sólo para amigos?'
  },
  'helpvar form_keywords' => {
    'lastUpdated' => '1252540500',
    'message' => 'Las palabras clave para los Archivos a incluir.'
  },
  'helpvar form_location' => {
    'lastUpdated' => '1276810289',
    'message' => 'La ubicación de los archivos incluidos.'
  },
  'helpvar form_promote' => {
    'lastUpdated' => '1252540545',
    'message' => 'Un botón para mover la imagen hacia arriba en el orden. Se usa para cambiar la posición de las imágenes.'
  },
  'helpvar form_rotateLeft' => {
    'lastUpdated' => '1272375319',
    'message' => 'Un botón para rotar la foto 90° hacia la izquierda.'
  },
  'helpvar form_rotateRight' => {
    'lastUpdated' => '1272375328',
    'message' => 'Un botón para rotar la foto 90° hacia la derecha.'
  },
  'helpvar form_sortBy' => {
    'lastUpdated' => '1276810314',
    'message' => 'Indica sobre cuál propiedad ordenar las fotos.'
  },
  'helpvar form_start' => {
    'lastUpdated' => '1215798092',
    'message' => 'Inicio del formulario'
  },
  'helpvar form_submit' => {
    'lastUpdated' => '1252540553',
    'message' => 'Enviar'
  },
  'helpvar form_synopsis' => {
    'lastUpdated' => '1252540570',
    'message' => 'Un Area HTML para la miniatura de la imagen.'
  },
  'helpvar form_title' => {
    'lastUpdated' => '1252540579',
    'message' => 'El Título del Álbum.'
  },
  'helpvar gallery_displayTitle' => {
    'lastUpdated' => '1252540619',
    'message' => 'Un condicional que indica si la Galería que contiene este Archivo está configurada para mostrar su Título o no.'
  },
  'helpvar gallery_menuTitle' => {
    'lastUpdated' => '1252540641',
    'message' => 'El Título para menú de la Galería que contiene este Archivo.'
  },
  'helpvar gallery_title' => {
    'lastUpdated' => '1252540655',
    'message' => 'El Título de la Galería que contiene este Archivo.'
  },
  'helpvar gallery_url' => {
    'lastUpdated' => '1252540665',
    'message' => 'El URL de la Galería que contiene este Archivo.'
  },
  'helpvar isAlbumThumbnail' => {
    'lastUpdated' => '1252540694',
    'message' => 'Un condicional que indica si el Archivo es la miniatura que identifica el Album o no.'
  },
  'helpvar isNewAlbum' => {
    'lastUpdated' => '1252540715',
    'message' => 'Un condicional que indica si el usuario está agregando un nuevo Album a la Galería o no.'
  },
  'helpvar isPending' => {
    'lastUpdated' => '1252540766',
    'message' => 'Un condicional que indica si el Album está pendiente por aprobación. Los usuarios que pueden editar el Album pueden revisarlo antes de que sean aprobados.'
  },
  'helpvar nextAlbum_thumbnailUrl' => {
    'lastUpdated' => '1252540784',
    'message' => 'El URL de la miniatura que representa al siguiente Album en la lista.'
  },
  'helpvar nextAlbum_title' => {
    'lastUpdated' => '1252540797',
    'message' => 'El Título del siguiente Album en la lista.'
  },
  'helpvar nextAlbum_url' => {
    'lastUpdated' => '1252540833',
    'message' => 'El URL del siguiente Album en la lista, en el orden que se muestra en la página Ver Lista de Albumes. Si no hay siguiente Album en la lista, la variable no existirá.'
  },
  'helpvar ownerUsername' => {
    'lastUpdated' => '1252540846',
    'message' => 'El nombre de usuario del propietario de este Album.'
  },
  'helpvar previousAlbum_thumbnailUrl' => {
    'lastUpdated' => '1252540860',
    'message' => 'El URL a la miniatura del Album anterior en la lista.'
  },
  'helpvar previousAlbum_title' => {
    'lastUpdated' => '1252540875',
    'message' => 'El Título del Album previo en la lista.'
  },
  'helpvar previousAlbum_url' => {
    'lastUpdated' => '1252540906',
    'message' => 'El URL al Album previo en la lista, en el orden en que se muestra en la página Listar Albumes. Si no hay Album previo, la variable no existe.'
  },
  'helpvar rssDate' => {
    'lastUpdated' => '1252540921',
    'message' => 'La fecha en formato RFC2822 para la Fuente RSS.'
  },
  'helpvar thumbnailUrl' => {
    'lastUpdated' => '1252540936',
    'message' => 'El URL para la miniatura del Archivo seleccionado como miniatura del Album.'
  },
  'helpvar url_addArchive' => {
    'lastUpdated' => '1252540958',
    'message' => 'El URL para agregar un grupo de Archivos al Album.'
  },
  'helpvar url_addNoClass' => {
    'lastUpdated' => '1252540992',
    'message' => 'El URL para agregar algo al Album. Es necesario agregar ";class=Class::Name" al final del URL.'
  },
  'helpvar url_addPhoto' => {
    'lastUpdated' => '1252541004',
    'message' => 'El URL para agregar una Foto al Album.'
  },
  'helpvar url_delete' => {
    'lastUpdated' => '1252541014',
    'message' => 'El URL para eliminar&nbsp; este Album'
  },
  'helpvar url_edit' => {
    'lastUpdated' => '1252541024',
    'message' => 'El URL para editar este Album.'
  },
  'helpvar url_listAlbums' => {
    'lastUpdated' => '1252541051',
    'message' => 'El URL a la página Listar Albumes de la Galería que le contiene.'
  },
  'helpvar url_listAlbumsRss' => {
    'lastUpdated' => '1252541069',
    'message' => 'El URL a la Fuente RSS de listar Albumes en la Galería.'
  },
  'helpvar url_listFilesForCurrentUser' => {
    'lastUpdated' => '1252541087',
    'message' => 'El URL a la página de listar Archivos para el usuario actual en la Galería.'
  },
  'helpvar url_listFilesForOwner' => {
    'lastUpdated' => '1252541107',
    'message' => 'El URL para la página listFilesForUser para el propietario de este Album.'
  },
  'helpvar url_search' => {
    'lastUpdated' => '1252545916',
    'message' => 'El URL para la página de búsqueda en la Galería.'
  },
  'helpvar url_slideshow' => {
    'lastUpdated' => '1252545976',
    'message' => 'El URL a la página de SlideShow del Album.'
  },
  'helpvar url_thumbnails' => {
    'lastUpdated' => '1252546005',
    'message' => 'El URL para las vistas en miniatura de este Album.'
  },
  'helpvar url_viewRss' => {
    'lastUpdated' => '1252546026',
    'message' => 'El URL para la Fuente RSS de este Album.'
  },
  'helpvar url_yes' => {
    'lastUpdated' => '1252546134',
    'message' => 'Confirmar la eliminación de este Album.'
  },
  'return to album' => {
    'lastUpdated' => '1252546160',
    'message' => 'Regresar al Album'
  },
  'rotate left' => {
    'lastUpdated' => '1272375358',
    'message' => '90° izq'
  },
  'rotate right' => {
    'lastUpdated' => '1272375367',
    'message' => '90° der'
  },
  'save' => {
    'lastUpdated' => '1252546167',
    'message' => 'Guardar'
  },
  'save message' => {
    'lastUpdated' => '1252546284',
    'message' => 'Las configuraciones del Album han sido almacenadas.'
  },
  'template add' => {
    'lastUpdated' => '1252546297',
    'message' => 'Agregar Album'
  },
  'template addArchive body' => {
    'lastUpdated' => '1252546334',
    'message' => 'Este formulario permite agregar paquetes .zip, .tgz y .tar.gz con archivos.'
  },
  'template addArchive title' => {
    'lastUpdated' => '1252546350',
    'message' => 'Agregar Paquetes Zip'
  },
  'template album thumbnail alt' => {
    'lastUpdated' => '1252546361',
    'message' => 'Miniatura para'
  },
  'template assetName' => {
    'lastUpdated' => '1252546370',
    'message' => 'Album'
  },
  'template delete message' => {
    'lastUpdated' => '1252546385',
    'message' => '¿Está seguro que desea eliminar este Album?'
  },
  'template delete no' => {
    'lastUpdated' => '1215795096',
    'message' => 'No'
  },
  'template delete yes' => {
    'lastUpdated' => '1215795084',
    'message' => 'Si'
  },
  'template edit' => {
    'lastUpdated' => '1252546401',
    'message' => 'Editar Album'
  },
  'template file creationDate' => {
    'lastUpdated' => '1252546425',
    'message' => 'Incorporado el'
  },
  'template file numberOfComments' => {
    'lastUpdated' => '1252546433',
    'message' => 'Comentarios'
  },
  'template upload archive' => {
    'lastUpdated' => '1252546444',
    'message' => 'Paquete Zip'
  },
  'template upload single' => {
    'lastUpdated' => '1252546471',
    'message' => 'Archivo Sencillo'
  },
  'template upload type' => {
    'lastUpdated' => '1252546491',
    'message' => 'Tipo de Archivo a Subir'
  },
  'template url' => {
    'lastUpdated' => '1252546520',
    'message' => 'Album'
  },
  'template url_addDescription' => {
    'lastUpdated' => '1252546536',
    'message' => 'Agregar descripción'
  },
  'template url_addPhoto' => {
    'lastUpdated' => '1252546544',
    'message' => 'Agregar foto'
  },
  'template url_delete' => {
    'lastUpdated' => '1252546558',
    'message' => 'Eliminar Album'
  },
  'template url_edit' => {
    'lastUpdated' => '1252546566',
    'message' => 'Editar Album'
  },
  'template url_slideshow' => {
    'lastUpdated' => '1252546579',
    'message' => 'Slideshow'
  },
  'template url_thumbnails' => {
    'lastUpdated' => '1252546589',
    'message' => 'Miniaturas'
  },
  'template use as thumbnail' => {
    'lastUpdated' => '1252546616',
    'message' => 'Usar como Miniatura Principal'
  },
  'what next' => {
    'lastUpdated' => '1252546631',
    'message' => '¿Ahora qué?'
  }
}
;

1;
